<?php

namespace App\Repository;

use App\Entity\ActiviteSecondaire;
use Doctrine\Bundle\DoctrineBundle\Repository\ServiceEntityRepository;
use Doctrine\Persistence\ManagerRegistry;
use Symfony\Component\Intl\Locale;

/**
 * @extends ServiceEntityRepository<ActiviteSecondaire>
 *
 * @method ActiviteSecondaire|null find($id, $lockMode = null, $lockVersion = null)
 * @method ActiviteSecondaire|null findOneBy(array $criteria, array $orderBy = null)
 * @method ActiviteSecondaire[]    findAll()
 * @method ActiviteSecondaire[]    findBy(array $criteria, array $orderBy = null, $limit = null, $offset = null)
 */
class ActiviteSecondaireRepository extends ServiceEntityRepository
{
    public function __construct(ManagerRegistry $registry)
    {
        parent::__construct($registry, ActiviteSecondaire::class);
    }

    public function add(ActiviteSecondaire $entity, bool $flush = false): void
    {
        $this->getEntityManager()->persist($entity);

        if ($flush) {
            $this->getEntityManager()->flush();
        }
    }

    public function remove(ActiviteSecondaire $entity, bool $flush = false): void
    {
        $this->getEntityManager()->remove($entity);

        if ($flush) {
            $this->getEntityManager()->flush();
        }
    }

    
    public function findIdsActiviteSecondaireActif()
    {
       $sql =  $this->createQueryBuilder('a')
                   ->select('a.id')
                   ->andWhere('a.actif = true')
                   ->getQuery()
                   ->getResult();

        $liste_ids = array_map(function($e) {
            return $e['id'];
        }, $sql);
        
        return $liste_ids;
    }


    public function findActiviteSecondaire($id_activite_principal)
    {
       return $this->createQueryBuilder('a')
                   ->andWhere('a.actif = true')
                   ->join('a.activite_primaire','activite_primaire')
                   ->andWhere('activite_primaire.id = :id_activite_principal')
                   ->setParameter('id_activite_principal', $id_activite_principal)
                   ->getQuery()
                   ->getResult();
    }

    public function findActiviteBySlug($slug)
    {
        $locale = Locale::getDefault();
        $qb = $this->createQueryBuilder('a')
                   ->join('a.translations','t')
                   ->andWhere('t.libelle_url =:slug')
                   ->andWhere('t.locale = :locale')
                   ->setParameter('slug', $slug)
                   ->setParameter('locale', $locale);

        return $qb->getQuery()->getOneOrNullResult();
    }

//    /**
//     * @return ActiviteSecondaire[] Returns an array of ActiviteSecondaire objects
//     */
//    public function findByExampleField($value): array
//    {
//        return $this->createQueryBuilder('a')
//            ->andWhere('a.exampleField = :val')
//            ->setParameter('val', $value)
//            ->orderBy('a.id', 'ASC')
//            ->setMaxResults(10)
//            ->getQuery()
//            ->getResult()
//        ;
//    }

//    public function findOneBySomeField($value): ?ActiviteSecondaire
//    {
//        return $this->createQueryBuilder('a')
//            ->andWhere('a.exampleField = :val')
//            ->setParameter('val', $value)
//            ->getQuery()
//            ->getOneOrNullResult()
//        ;
//    }
}
